@@ -1,6 +1,6 @@
 from .exception import PipelineError, PipelineOutputError, PipelineMessageError
-from .message import Message, DescribeMessage
-from .tap import Settings, DestinationTap, SourceTap, TapKind
+from .message import Message, DescribeMessage, serialize_message, deserialize_message
+from .tap import DestinationTap, SourceTap, TapKind
 from .worker import (
     ProducerSettings,
     Producer,
@@ -10,6 +10,7 @@ from .worker import (
     Splitter,
 )
 from .manager import Pipeline
+from .helpers import Settings
 
 
 __all__ = [
@@ -28,5 +29,7 @@ __all__ = [
     "Splitter",
     "Message",
     "DescribeMessage",
+    "serialize_message",
+    "deserialize_message",
     "Pipeline",
 ]
